@@ -34,6 +34,18 @@ class TestArrays(utils.PfpTestCase):
             stdout="a",
         )
 
+    def test_cast_from_dex(self):
+        dom = self._test_parse_build(
+            "",
+            """
+                local ubyte cur = 7;
+                local uint test1 = (uint)(10);
+                local uint test2 = (uint)((cur & 0x7f) << 7);
+                Printf("%u,%u", test1, test2);
+            """,
+            stdout="10,896",
+        )
+
 
 if __name__ == "__main__":
     unittest.main()
