@@ -69,6 +69,22 @@ class TestCompatInterface(utils.PfpTestCase):
     def tearDown(self):
         pass
 
+    def test_boolean_constants(self):
+        dom = self._test_parse_build(
+            "",
+            """
+            local int bool_val;
+            bool_val = true;
+            bool_val = True;
+            bool_val = TRUE;
+
+            bool_val = false;
+            bool_val = False;
+            bool_val = FALSE;
+            """,
+            predefines=True,
+        )
+
     def test_color_constants(self):
         # shouldn't error
         dom = self._test_parse_build(
@@ -116,11 +132,11 @@ class TestCompatIO(utils.PfpTestCase):
         dom = self._test_parse_build(
             "\x80\x01",
             """
+                BigEndian();
                 local ushort blah = ReadUShort();
                 Printf("%d|", blah);
                 Printf("%d", FTell());
             """,
-            verify=False,
             stdout="32769|0",
         )
 
@@ -136,7 +152,6 @@ class TestCompatIO(utils.PfpTestCase):
                 uchar b;
                 Printf("%d%d", a, b);
             """,
-            verify=False,
             stdout="ab9798",
         )
 
@@ -187,7 +202,6 @@ class TestCompatIO(utils.PfpTestCase):
                 Printf("%d", FSeek(FTell() + 4));
                 Printf("%d", FSeek(FTell() + 2));
             """,
-            verify=False,
             stdout="0-1",
         )
 
@@ -209,7 +223,6 @@ class TestCompatIO(utils.PfpTestCase):
                 local int rv6 = FSeek(0);
                 local int pos7 = FTell();
             """,
-            verify=False,
         )
         self.assertEqual(dom.pos1, 0)
         self.assertEqual(dom.rv1, 0)
@@ -276,7 +289,6 @@ class TestCompatIO(utils.PfpTestCase):
                 local int fskip_rv2 = FSkip(3);
                 local int pos2 = FTell();
             """,
-            verify=False,
         )
         self.assertEqual(dom.fskip_rv1, 0)
         self.assertEqual(dom.pos1, 1)
@@ -484,6 +496,23 @@ class TestCompatString(utils.PfpTestCase):
             stdout="-1",
         )
 
+    def test_memcmp(self):
+        dom = self._test_parse_build(
+            "",
+            r"""
+            local string a = "hellothere";
+            local string b = "helloblah";
+            Printf("%d\n", Memcmp(a, b, 1));
+            Printf("%d\n", Memcmp(a, b, 2));
+            Printf("%d\n", Memcmp(a, b, 3));
+            Printf("%d\n", Memcmp(a, b, 4));
+            Printf("%d\n", Memcmp(a, b, 5));
+            Printf("%d\n", Memcmp(a, b, 6));
+            Printf("%d\n", Memcmp(b, a, 6));
+            """,
+            stdout="0\n0\n0\n0\n0\n1\n-1\n",
+        )
+
 
 class TestCompatTools(utils.PfpTestCase):
     def setUp(self):
@@ -508,7 +537,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:3start-size:5-5start-size:17-5start-size:28-5",
-            verify=False,
             predefines=True,
         )
 
@@ -528,7 +556,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:3start-size:5-5start-size:17-5start-size:28-5",
-            verify=False,
             predefines=True,
         )
 
@@ -548,7 +575,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:3start-size:5-5start-size:17-5start-size:28-5",
-            verify=False,
             predefines=True,
         )
 
@@ -568,7 +594,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:3start-size:5-5start-size:22-5start-size:33-5",
-            verify=False,
             predefines=True,
         )
 
@@ -593,7 +618,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:3start-size:5-5start-size:22-5start-size:33-5",
-            verify=False,
             predefines=True,
         )
 
@@ -618,7 +642,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:3start-size:5-5start-size:16-5start-size:27-5",
-            verify=False,
             predefines=True,
         )
 
@@ -647,7 +670,6 @@ class TestCompatTools(utils.PfpTestCase):
                 }
             """,
             stdout="count:2start-size:5-5start-size:16-5",
-            verify=False,
             predefines=True,
         )
 
@@ -662,7 +684,6 @@ class TestCompatTools(utils.PfpTestCase):
                 index = FindNext();
                 Printf("%d", index);
             """,
-            verify=False,
             stdout="5,16,27",
         )
 
